@echo off
setlocal enabledelayedexpansion

:: 设置输出文件
set "logFile=%userprofile%\Desktop\PreventWindowsUpdateFromInstallingDisplayLinkDrivers.log"
echo Preventing Windows Update from Installing DisplayLink Drivers >> "%logFile%"

:: 1. 创建或修改设备安装限制
echo Creating or modifying device installation restrictions...
reg add "HKLM\SOFTWARE\Policies\Microsoft\Windows\DeviceInstall\Restrictions" /v DenyDeviceIDs /t REG_DWORD /d 1 /f
if %errorlevel%==0 (
    echo Device installation restrictions set successfully.
    echo Device installation restrictions set successfully. >> "%logFile%"
) else (
    echo Failed to set device installation restrictions.
    echo Failed to set device installation restrictions. >> "%logFile%"
)

:: 2. 添加DisplayLink设备ID到禁止列表
echo Adding DisplayLink device IDs to the deny list...
reg add "HKLM\SOFTWARE\Policies\Microsoft\Windows\DeviceInstall\Restrictions" /v DenyDeviceIDsList /t REG_MULTI_SZ /d "USB\VID_17E9&PID_4353\0" /f
if %errorlevel%==0 (
    echo DisplayLink device IDs added to the deny list successfully.
    echo DisplayLink device IDs added to the deny list successfully. >> "%logFile%"
) else (
    echo Failed to add DisplayLink device IDs to the deny list.
    echo Failed to add DisplayLink device IDs to the deny list. >> "%logFile%"
)

:: 3. 创建或修改驱动程序安装限制
echo Creating or modifying driver installation restrictions...
reg add "HKLM\SOFTWARE\Policies\Microsoft\Windows\DeviceInstall\Restrictions" /v DenyDriverInstallationFromWindowsUpdate /t REG_DWORD /d 1 /f
if %errorlevel%==0 (
    echo Driver installation restrictions set successfully.
    echo Driver installation restrictions set successfully. >> "%logFile%"
) else (
    echo Failed to set driver installation restrictions.
    echo Failed to set driver installation restrictions. >> "%logFile%"
)

:: 4. 配置Windows Update以排除驱动程序更新
echo Configuring Windows Update to exclude driver updates...

:: 使用组策略配置Windows Update行为
echo Configuring Group Policy to exclude driver updates...
reg add "HKLM\SOFTWARE\Policies\Microsoft\Windows\WindowsUpdate" /v ExcludeWUDriversInQualityUpdate /t REG_DWORD /d 1 /f
if %errorlevel%==0 (
    echo Windows Update configured to exclude driver updates successfully.
    echo Windows Update configured to exclude driver updates successfully. >> "%logFile%"
) else (
    echo Failed to configure Windows Update to exclude driver updates.
    echo Failed to configure Windows Update to exclude driver updates. >> "%logFile%"
)

:: 5. 定期监控和恢复机制
echo Setting up a scheduled task to check and restore settings...

:: 创建任务计划
schtasks /create /tn "CheckAndRestoreDisplayLinkSettings" /tr "%~dpnx0" /sc daily /st 02:00 /ru "SYSTEM" /f
if %errorlevel%==0 (
    echo Scheduled task created to check and restore settings daily at 2:00 AM.
    echo Scheduled task created to check and restore settings daily at 2:00 AM. >> "%logFile%"
) else (
    echo Failed to create scheduled task.
    echo Failed to create scheduled task. >> "%logFile%"
)

:: 提示用户查看结果
echo All settings have been applied. Results have been saved to %logFile%
pause